# OneNeuron_pypi
OneNeuron_pypi

# How to use

```python
from oneNeuron.__perceptron__ import Perceptron
#get X and y and then use below commands
model = Perceptron(eta=eta, epochs=epochs)
model.fit(X, y)
```
# Reference
[Official python docs](https://packaging.python.org/tutorials/packaging-projects/)

[github doc for gihub actions](https://docs.github.com/en/actions/guides/building-and-testing-python#publishing-to-package-registries)
